@@ -7,11 +7,12 @@ from grpc import StatusCode
 from grpc_testing import server_from_dictionary, strict_real_time
 
 from pynumaflow._constants import DATUM_KEY
-from pynumaflow.function._dtypes import (
+from pynumaflow.function import (
     Message,
     Messages,
     Datum,
 )
+from pynumaflow.function._dtypes import DROP
 from pynumaflow.function.generated import udfunction_pb2
 from pynumaflow.function.server import UserDefinedFunctionServicer
 
@@ -29,6 +30,10 @@ def map_handler(key: str, datum: Datum) -> Messages:
     return messages
 
 
+def err_map_handler(_: str, __: Datum) -> Messages:
+    raise RuntimeError("Something is fishy!")
+
+
 def mock_message():
     msg = bytes("test_mock_message", encoding="utf-8")
     return msg
@@ -45,13 +50,49 @@ def mock_watermark():
 
 
 class TestServer(unittest.TestCase):
-    def __init__(self, method_name) -> None:
-        super().__init__(method_name)
-
+    def setUp(self) -> None:
         my_servicer = UserDefinedFunctionServicer(map_handler)
         services = {udfunction_pb2.DESCRIPTOR.services_by_name["UserDefinedFunction"]: my_servicer}
         self.test_server = server_from_dictionary(services, strict_real_time())
 
+    def test_udferr(self):
+        my_servicer = UserDefinedFunctionServicer(err_map_handler)
+        services = {udfunction_pb2.DESCRIPTOR.services_by_name["UserDefinedFunction"]: my_servicer}
+        self.test_server = server_from_dictionary(services, strict_real_time())
+
+        event_time_timestamp = _timestamp_pb2.Timestamp()
+        event_time_timestamp.FromDatetime(dt=mock_event_time())
+        watermark_timestamp = _timestamp_pb2.Timestamp()
+        watermark_timestamp.FromDatetime(dt=mock_watermark())
+
+        request = udfunction_pb2.Datum(
+            value=mock_message(),
+            event_time=udfunction_pb2.EventTime(event_time=event_time_timestamp),
+            watermark=udfunction_pb2.Watermark(watermark=watermark_timestamp),
+        )
+
+        method = self.test_server.invoke_unary_unary(
+            method_descriptor=(
+                udfunction_pb2.DESCRIPTOR.services_by_name["UserDefinedFunction"].methods_by_name[
+                    "MapFn"
+                ]
+            ),
+            invocation_metadata={
+                (DATUM_KEY, "test"),
+                ("this_metadata_will_be_skipped", "test_ignore"),
+            },
+            request=request,
+            timeout=1,
+        )
+
+        response, metadata, code, details = method.termination()
+        self.assertEqual(1, len(response.elements))
+        self.assertEqual(DROP.decode(), response.elements[0].key)
+        self.assertEqual(
+            b"",
+            response.elements[0].value,
+        )
+
     def test_is_ready(self):
         method = self.test_server.invoke_unary_unary(
             method_descriptor=(
